@@ -16,7 +16,7 @@
 #
 ''' Provides the different actions that can be performed by layman.'''
 
-__version__ = "$Id: action.py 240 2006-09-06 07:45:11Z wrobel $"
+__version__ = "$Id: action.py 273 2006-12-30 15:54:50Z wrobel $"
 
 #===============================================================================
 #
@@ -116,14 +116,14 @@ class Sync:
                     + str(error))
 
         if success:
-            OUT.info('\nSuccess:\n------\n')
+            OUT.info('\nSuccess:\n------\n', 3)
             for i in success:
-                OUT.info(i)
+                OUT.info(i, 3)
 
         if warnings:
-            OUT.warn('\nErrors:\n------\n')
+            OUT.warn('\nErrors:\n------\n', 2)
             for i in warnings:
-                OUT.warn(i + '\n')
+                OUT.warn(i + '\n', 2)
 
 
 #===============================================================================
@@ -161,12 +161,12 @@ class Add:
             if overlay:
                 try:
                     self.db.add(overlay)
-                    OUT.info('Successfully added overlay "' + i + '".', 1)
+                    OUT.info('Successfully added overlay "' + i + '".', 2)
                 except Exception, error:
                     OUT.warn('Failed to add overlay "' + i + '".\nError was: '
-                             + str(error))
+                             + str(error), 2)
             else:
-                OUT.warn('Overlay "' + i + '" does not exist!')
+                OUT.warn('Overlay "' + i + '" does not exist!', 2)
 
 #===============================================================================
 #
@@ -199,12 +199,12 @@ class Delete:
             if overlay:
                 try:
                     self.db.delete(overlay)
-                    OUT.info('Successfully deleted overlay "' + i + '".', 1)
+                    OUT.info('Successfully deleted overlay "' + i + '".', 2)
                 except Exception, error:
                     OUT.warn('Failed to delete overlay "' + i + '".\nError was: '
-                             + str(error))
+                             + str(error), 2)
             else:
-                OUT.warn('Overlay "' + i + '" does not exist!')
+                OUT.warn('Overlay "' + i + '" does not exist!', 2)
 
 #===============================================================================
 #
@@ -268,15 +268,15 @@ class List:
             if i[1]:
                 # Is this an official overlay?
                 if i[2]:
-                    OUT.info(i[0])
+                    OUT.info(i[0], 1)
                 # Unofficial overlays will only be listed if we are not
                 # checking or listing verbose
                 elif self.config['nocheck'] or self.config['verbose']:
                     # Give a reason why this is marked yellow if it is a verbose
                     # listing
                     if self.config['verbose']:
-                        OUT.warn('*** This is no official gentoo overlay ***\n')
-                    OUT.warn(i[0])
+                        OUT.warn('*** This is no official gentoo overlay ***\n', 1)
+                    OUT.warn(i[0], 1)
             # Unsupported overlays will only be listed if we are not checking
             # or listing verbose
             elif self.config['nocheck'] or self.config['verbose']:
@@ -311,15 +311,15 @@ class ListLocal:
             if i[1]:
                 # Is this an official overlay?
                 if i[2]:
-                    OUT.info(i[0])
+                    OUT.info(i[0], 1)
                 # Unofficial overlays will only be listed if we are not
                 # checking or listing verbose
                 else:
                     # Give a reason why this is marked yellow if it is a verbose
                     # listing
                     if self.config['verbose']:
-                        OUT.warn('*** This is no official gentoo overlay ***\n')
-                    OUT.warn(i[0])
+                        OUT.warn('*** This is no official gentoo overlay ***\n', 1)
+                    OUT.warn(i[0], 1)
             # Unsupported overlays will only be listed if we are not checking
             # or listing verbose
             else:
