@@ -16,7 +16,7 @@
 #
 '''Defines the configuration options and provides parsing functionality.'''
 
-__version__ = "$Id: config.py 240 2006-09-06 07:45:11Z wrobel $"
+__version__ = "$Id: config.py 273 2006-12-30 15:54:50Z wrobel $"
 
 #===============================================================================
 #
@@ -158,6 +158,25 @@ class Config(object):
                          action = 'store_true',
                          help = 'Increase amount of output.')
 
+        group.add_option('-q',
+                         '--quiet',
+                         action = 'store_true',
+                         help = 'Yield no output. Please be careful with this op'
+                         'tion: If the processes spawned by layman when adding o'
+                         'r synchronizing overlays require any input layman will'
+                         ' hang without telling you why. This might happen for e'
+                         'xample if your overlay resides in subversion and the S'
+                         'SL certificate of the server needs acceptance.')
+
+        group.add_option('-Q',
+                         '--quietness',
+                         action = 'store',
+                         type = 'int',
+                         default = '4',
+                         help = 'Set the level of output (0-4). Default: 4. Once'
+                         ' you set this below 2 the same warning as given for --'
+                         'quiet applies! ')
+
         group.add_option('-k',
                          '--nocheck',
                          action = 'store_true',
@@ -187,6 +206,15 @@ class Config(object):
         self.config = ConfigParser.ConfigParser(self.defaults)
         self.config.add_section('MAIN')
 
+        # handle quietness
+        if self['quiet']:
+            OUT.set_info_level(1)
+            OUT.set_warn_level(1)
+            self.defaults['quietness'] = 0
+        elif 'quietness' in self.keys():
+            OUT.set_info_level(int(self['quietness']))
+            OUT.set_warn_level(int(self['quietness']))
+
         OUT.debug('Reading config file at ' + self.defaults['config'], 8)
 
         self.config.read(self.defaults['config'])
