@@ -16,7 +16,7 @@
 #
 '''Handles different storage files.'''
 
-__version__ = "$Id: db.py 238 2006-09-05 21:40:31Z wrobel $"
+__version__ = "$Id: db.py 273 2006-12-30 15:54:50Z wrobel $"
 
 #===============================================================================
 #
@@ -51,7 +51,12 @@ class DB(Overlays):
         else:
             ignore = 1
 
-        Overlays.__init__(self, [config['local_list'], ], ignore)
+        quiet = int(config['quietness']) < 3
+
+        Overlays.__init__(self, 
+                          [config['local_list'], ], 
+                          ignore, 
+                          quiet)
 
         OUT.debug('DB handler initiated', 6)
 
@@ -179,7 +184,10 @@ class DB(Overlays):
         overlay = self.select(overlay_name)
 
         if overlay:
-            overlay.sync(self.config['storage'])
+            result = overlay.sync(self.config['storage'])
+            if result:
+                raise Exception('Syncing overlay "' + overlay_name + 
+                                '" returned status ' + str(result) + '!')
         else:
             raise Exception('No such overlay ("' + overlay_name + '")!')
 
@@ -210,7 +218,9 @@ class RemoteDB(Overlays):
         else:
             ignore = 0
 
-        Overlays.__init__(self, paths, ignore)
+        quiet = int(config['quietness']) < 3
+
+        Overlays.__init__(self, paths, ignore, quiet)
 
     def cache(self):
         '''
