@@ -14,6 +14,7 @@
 # Author(s):
 #             Gunnar Wrobel <wrobel@gentoo.org>
 #             Stefan Schweizer <genstef@gentoo.org>
+''' Git overlay support.'''
 
 __version__ = "$Id: git.py 146 2006-05-27 09:52:36Z wrobel $"
 
@@ -26,8 +27,6 @@ __version__ = "$Id: git.py 146 2006-05-27 09:52:36Z wrobel $"
 from   layman.utils             import path
 from   layman.overlays.overlay  import Overlay
 
-from   layman.debug             import OUT
-
 #===============================================================================
 #
 # Class GitOverlay
@@ -39,22 +38,26 @@ class GitOverlay(Overlay):
 
     type = 'Git'
 
-    binary_command  = '/usr/bin/git' 
-    
+    binary_command  = '/usr/bin/git'
+
     def add(self, base):
+        '''Add overlay.'''
 
         self.supported()
 
-        return self.cmd(self.binary_command + ' clone ' + self.src + '/ ' + 
-                        path([base, self.name]))
+        return self.cmd(self.binary_command + ' clone "' + self.src + '/" "'
+                        + path([base, self.name]) + '"')
 
     def sync(self, base):
+        '''Sync overlay.'''
 
         self.supported()
 
-        return self.cmd('cd ' + path([base, self.name]) + ' && ' 
+        return self.cmd('cd "' + path([base, self.name]) + '" && '
                         + self.binary_command + ' pull')
 
     def supported(self):
+        '''Overlay type supported?'''
 
-        return Overlay.supported(self, [(self.binary_command,  'git', 'dev-util/git'),])
+        return Overlay.supported(self, [(self.binary_command,  'git',
+                                         'dev-util/git'),])
