@@ -16,7 +16,7 @@
 #
 ''' Tar overlay support.'''
 
-__version__ = "$Id: tar.py 236 2006-09-05 20:39:37Z wrobel $"
+__version__ = "$Id: tar.py 273 2006-12-30 15:54:50Z wrobel $"
 
 #===============================================================================
 #
@@ -64,7 +64,7 @@ class TarOverlay(Overlay):
 
     binary = '/bin/tar'
 
-    def __init__(self, xml, ignore = False):
+    def __init__(self, xml, ignore = 0, quiet = False):
 
         Overlay.__init__(self, xml, ignore)
 
